'use strict'

exports.__esModule = true
exports.Column = void 0

var _propTypes = _interopRequireDefault(require('prop-types'))

var React = _interopRequireWildcard(require('react'))

var _clsx = _interopRequireDefault(require('clsx'))

var _Frame = require('./Frame')

var _Layout = require('./Layout')

var _styles = require('./styles')

function _getRequireWildcardCache() {
  if (typeof WeakMap !== 'function') return null
  var cache = new WeakMap()
  _getRequireWildcardCache = function () {
    return cache
  }
  return cache
}

function _interopRequireWildcard(obj) {
  if (obj && obj.__esModule) {
    return obj
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return {default: obj}
  }
  var cache = _getRequireWildcardCache()
  if (cache && cache.has(obj)) {
    return cache.get(obj)
  }
  var newObj = {}
  var hasPropertyDescriptor =
    Object.defineProperty && Object.getOwnPropertyDescriptor
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor
        ? Object.getOwnPropertyDescriptor(obj, key)
        : null
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc)
      } else {
        newObj[key] = obj[key]
      }
    }
  }
  newObj.default = obj
  if (cache) {
    cache.set(obj, newObj)
  }
  return newObj
}

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

const __reactCreateElement__ = React.createElement

/**
 * A component that distributes its items in a column without wrapping like so:
 *
 * ☐
 * ☐
 * ☐
 * ☐
 *
 */
const Column = React.forwardRef(
  ({className, align, distribute, gap, reverse = false, ...props}, ref) => {
    const prop = (0, _Layout.useLayout)().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(_Frame.Frame, {
      ref: ref,
      display: 'flex',
      className: (0, _clsx.default)(
        className,
        prop(_styles.alignItems, align),
        prop(_styles.justifyContent, distribute),
        prop(reverseStyle, reverse),
        prop(gapStyle(reverse), gap)
      ),
      ...props,
    })
  }
)
exports.Column = Column

const reverseStyle = (reverse) =>
  _styles.flexDirection[reverse ? 'reversedColumn' : 'column'] +
  (reverse ? _styles.justifyContent.end : '') // @ts-ignore

const gapStyle = (reverse) => (gapProp, queryName) => {
  const reversed =
    !reverse || typeof reverse === 'boolean' ? reverse : reverse[queryName]
  const marginDirection = reversed ? 'bottom' : 'top'
  return ({gap}) =>
    `&>* + *{margin-${marginDirection}:${gap[gapProp]}!important;}`
}
