'use strict'

exports.__esModule = true
exports.GridItem = exports.Grid = void 0

var _propTypes = _interopRequireDefault(require('prop-types'))

var React = _interopRequireWildcard(require('react'))

var _clsx = _interopRequireDefault(require('clsx'))

var _Frame = require('./Frame')

var _Layout = require('./Layout')

var _styles = require('./styles')

var _utils = require('./utils')

function _getRequireWildcardCache() {
  if (typeof WeakMap !== 'function') return null
  var cache = new WeakMap()
  _getRequireWildcardCache = function () {
    return cache
  }
  return cache
}

function _interopRequireWildcard(obj) {
  if (obj && obj.__esModule) {
    return obj
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return {default: obj}
  }
  var cache = _getRequireWildcardCache()
  if (cache && cache.has(obj)) {
    return cache.get(obj)
  }
  var newObj = {}
  var hasPropertyDescriptor =
    Object.defineProperty && Object.getOwnPropertyDescriptor
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor
        ? Object.getOwnPropertyDescriptor(obj, key)
        : null
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc)
      } else {
        newObj[key] = obj[key]
      }
    }
  }
  newObj.default = obj
  if (cache) {
    cache.set(obj, newObj)
  }
  return newObj
}

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

const __reactCreateElement__ = React.createElement
const Grid = React.forwardRef(
  (
    {
      className,
      alignX,
      alignY,
      cols,
      distributeX,
      distributeY,
      gap,
      inline,
      rows,
      ...props
    },
    ref
  ) => {
    const prop = (0, _Layout.useLayout)().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(_Frame.Frame, {
      ref: ref,
      className: (0, _clsx.default)(
        className,
        prop(gridStyle, inline || false),
        prop(colsStyle, cols),
        prop(rowsStyle, rows),
        prop(_styles.justifyItems, alignX),
        prop(_styles.alignItems, alignY),
        prop(_styles.justifyContent, distributeX),
        prop(_styles.alignContent, distributeY),
        prop(gapStyle, gap)
      ),
      ...props,
    })
  }
)
exports.Grid = Grid
const GridItem = React.forwardRef(
  (
    {className, alignX, alignY, colStart, colEnd, rowStart, rowEnd, ...props},
    ref
  ) => {
    const prop = (0, _Layout.useLayout)().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(_Frame.Frame, {
      ref: ref,
      className: (0, _clsx.default)(
        className,
        prop(_styles.justifySelf, alignX),
        prop(_styles.alignSelf, alignY),
        prop(colStartStyle, colStart),
        prop(colEndStyle, colEnd),
        prop(rowStartStyle, rowStart),
        prop(rowEndStyle, rowEnd)
      ),
      ...props,
    })
  }
)
exports.GridItem = GridItem

const gridStyle = (inline) => ({
  display: inline ? 'inline-grid' : 'grid',
})

function _ref(col) {
  return (0, _utils.unit)('grid-template-columns', col)
}

const colsStyle = (cols) => {
  let value
  if (Array.isArray(cols)) value = cols
  // ie doesn't have repeat
  else value = new Array(cols).fill('1fr')
  return {
    gridTemplateColumns: value.map(_ref).join(' '),
  }
}

function _ref2(col) {
  return (0, _utils.unit)('grid-template-rows', col)
}

const rowsStyle = (rows) => {
  let value
  if (Array.isArray(rows)) value = rows
  // ie doesn't have repeat
  else value = new Array(rows).fill('1fr')
  return {
    gridTemplateRows: value.map(_ref2).join(' '),
  }
}

const gapStyle = (gapProp) => ({gap}) => ({
  gridGap: Array.isArray(gapProp)
    ? gapProp.map((p) => gap[p]).join(' ')
    : `${gap[gapProp]} ${gap[gapProp]}`,
})

const colStartStyle = (gridColumnStart) => ({
  gridColumnStart,
})

const colEndStyle = (gridColumnEnd) => ({
  gridColumnEnd,
})

const rowStartStyle = (gridRowStart) => ({
  gridRowStart,
})

const rowEndStyle = (gridRowEnd) => ({
  gridRowEnd,
})
