'use strict'

exports.__esModule = true
exports.LayerItem = exports.Layer = void 0

var _propTypes = _interopRequireDefault(require('prop-types'))

var React = _interopRequireWildcard(require('react'))

var _clsx = _interopRequireDefault(require('clsx'))

var _Frame = require('./Frame')

var _Layout = require('./Layout')

function _getRequireWildcardCache() {
  if (typeof WeakMap !== 'function') return null
  var cache = new WeakMap()
  _getRequireWildcardCache = function () {
    return cache
  }
  return cache
}

function _interopRequireWildcard(obj) {
  if (obj && obj.__esModule) {
    return obj
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return {default: obj}
  }
  var cache = _getRequireWildcardCache()
  if (cache && cache.has(obj)) {
    return cache.get(obj)
  }
  var newObj = {}
  var hasPropertyDescriptor =
    Object.defineProperty && Object.getOwnPropertyDescriptor
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor
        ? Object.getOwnPropertyDescriptor(obj, key)
        : null
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc)
      } else {
        newObj[key] = obj[key]
      }
    }
  }
  newObj.default = obj
  if (cache) {
    cache.set(obj, newObj)
  }
  return newObj
}

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

const __reactCreateElement__ = React.createElement

/**
 * A component that makes its items layer on top of each other:
 *   ___
 *  | ☐ |
 *   ‾‾‾
 */
const Layer = React.forwardRef((props, ref) =>
  /*#__PURE__*/ __reactCreateElement__(_Frame.Frame, {
    ref: ref,
    position: 'relative',
    ...props,
  })
)
exports.Layer = Layer
const LayerItem = React.forwardRef(
  ({className, placement, offset, z, ...props}, ref) => {
    const prop = (0, _Layout.useLayout)().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(_Frame.Frame, {
      ref: ref,
      position: 'absolute',
      className: (0, _clsx.default)(
        className,
        prop(placementStyle(offset), placement),
        prop(zStyle, z)
      ),
      ...props,
    })
  }
)
exports.LayerItem = LayerItem

const placementStyle = (offsetProp) => (value, queryName) => {
  if (value === 'center') {
    return `top:50%;left:50%;transform:translate(-50%,-50%);`
  }

  const offset = !offsetProp
    ? 0
    : typeof offsetProp === 'object'
    ? offsetProp[queryName]
    : offsetProp
  const lValue = value.toLowerCase()
  const yProp =
    lValue.indexOf('top') > -1
      ? 'top'
      : lValue.indexOf('bottom') > -1
      ? 'bottom'
      : void 0
  const xProp =
    lValue.indexOf('left') > -1
      ? 'left'
      : lValue.indexOf('right') > -1
      ? 'right'
      : void 0
  const styles = {}
  if (yProp) styles[yProp] = offset
  if (xProp) styles[xProp] = offset

  if (value === 'left' || value === 'right') {
    styles.top = '50%'
    styles.transform = 'translateY(-50%)'
  }

  if (value === 'bottom' || value === 'top') {
    styles.left = '50%'
    styles.transform = 'translateX(-50%)'
  }

  return styles
}

const zStyle = (value) => ({
  zIndex: value,
})
