'use strict'

exports.__esModule = true
exports.LayoutProvider = exports.useLayout = void 0

var _propTypes = _interopRequireDefault(require('prop-types'))

var React = _interopRequireWildcard(require('react'))

var _react2 = _interopRequireWildcard(require('@-ui/react'))

var _mq = _interopRequireDefault(require('@-ui/mq'))

function _getRequireWildcardCache() {
  if (typeof WeakMap !== 'function') return null
  var cache = new WeakMap()
  _getRequireWildcardCache = function () {
    return cache
  }
  return cache
}

function _interopRequireWildcard(obj) {
  if (obj && obj.__esModule) {
    return obj
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return {default: obj}
  }
  var cache = _getRequireWildcardCache()
  if (cache && cache.has(obj)) {
    return cache.get(obj)
  }
  var newObj = {}
  var hasPropertyDescriptor =
    Object.defineProperty && Object.getOwnPropertyDescriptor
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor
        ? Object.getOwnPropertyDescriptor(obj, key)
        : null
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc)
      } else {
        newObj[key] = obj[key]
      }
    }
  }
  newObj.default = obj
  if (cache) {
    cache.set(obj, newObj)
  }
  return newObj
}

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

const __reactCreateElement__ = React.createElement
const defaultMq = (0, _mq.default)({})

defaultMq.prop = (styleGetter, value) => {
  if (value === void 0) return
  /* istanbul ignore next */

  if (__DEV__) {
    if (typeof value === 'object' && !Array.isArray(value)) {
      throw new Error(
        '@-ui/layout is attempting to use media queries without a <LayoutProvider> component. This is not allowed.'
      )
    }
  } // Single style

  return _react2.default.one(
    typeof styleGetter === 'function'
      ? styleGetter(value)
      : typeof value === 'string'
      ? styleGetter[value]
      : ''
  )()
}

const LayoutContext = React.createContext({
  styles: _react2.default,
  mediaQueries: {},
  mq: defaultMq,
})

const useLayout = () => React.useContext(LayoutContext)

exports.useLayout = useLayout
const emptyObj = {}

const LayoutProvider = ({mediaQueries = emptyObj, children}) => {
  const styles = (0, _react2.useDash)()
  const context = React.useMemo(() => {
    const mq = (0, _mq.default)(mediaQueries)

    mq.prop = (styleGetter, value, context) => {
      if (value === void 0) return

      function _ref(stylesWithMq, queryName) {
        const queryValue = value[queryName]

        if (value[queryName] !== void 0) {
          stylesWithMq[queryName] =
            typeof styleGetter === 'function'
              ? styleGetter(queryValue, queryName, context)
              : styleGetter[queryValue]
        }

        return stylesWithMq
      }

      if (typeof value === 'object' && !Array.isArray(value)) {
        // Media queries
        const mqObj = mq(Object.keys(mediaQueries).reduce(_ref, {}))
        return styles.one(mqObj)()
      } // Single style

      return styles.one(
        typeof styleGetter === 'function'
          ? styleGetter(value)
          : typeof value === 'string'
          ? styleGetter[value]
          : ''
      )()
    }

    return {
      styles,
      mediaQueries,
      mq,
    }
  }, [styles, mediaQueries])
  return /*#__PURE__*/ __reactCreateElement__(LayoutContext.Provider, {
    value: context,
    children: children,
  })
}

exports.LayoutProvider = LayoutProvider
LayoutProvider.propTypes = {
  mediaQueries: _propTypes.default.object,
}
