import _pt from 'prop-types'
import * as React from 'react'
const __reactCreateElement__ = React.createElement
import clsx from 'clsx'
import {Frame} from './Frame'
import {useLayout} from './Layout'
import {justifyContent, flexDirection} from './styles'

/**
 * A row directional component that distributes its items in a cluster like so:
 *
 * ☐☐☐☐☐
 * ☐☐☐☐☐☐
 * ☐☐☐☐☐
 * ☐☐☐
 *
 * or
 *
 *  ☐☐☐☐☐
 * ☐☐☐☐☐☐
 *  ☐☐☐☐☐
 *    ☐☐☐
 *
 * Some use cases include input chips and tags.
 */
export const Cluster = React.forwardRef(
  ({className, gap, reverse = false, ...props}, ref) => {
    const {
      styles,
      mq: {prop},
    } = useLayout()
    return /*#__PURE__*/ __reactCreateElement__(Frame, {
      ref: ref,
      className: clsx(
        className,
        styles.one(`display:flex;flex-wrap:wrap;`)(),
        prop(reverseStyle, reverse),
        prop(gapStyle(reverse), gap)
      ),
      ...props,
    })
  }
)

const reverseStyle = (reverse) =>
  flexDirection[reverse ? 'reversedRow' : 'row'] +
  justifyContent[reverse ? 'end' : 'start']

const gapStyle = (reverse) => (gapProp, queryName) => {
  const reversed =
    !reverse || typeof reverse === 'boolean' ? reverse : reverse[queryName]
  const marginDirection = reversed ? 'right' : 'left'
  return ({gap}) =>
    `margin-top:calc(-1 * ${gap[gapProp]})!important;margin-${marginDirection}:calc(-1 * ${gap[gapProp]})!important;&>*{margin-top:${gap[gapProp]}!important;margin-${marginDirection}:${gap[gapProp]}!important;}`
}
