import _pt from 'prop-types'
import * as React from 'react'
const __reactCreateElement__ = React.createElement
import clsx from 'clsx'
import {Frame} from './Frame'
import {useLayout} from './Layout'
import {flexDirection, alignItems, justifyContent} from './styles'

/**
 * A component that distributes its items in a column without wrapping like so:
 *
 * ☐
 * ☐
 * ☐
 * ☐
 *
 */
export const Column = React.forwardRef(
  ({className, align, distribute, gap, reverse = false, ...props}, ref) => {
    const prop = useLayout().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(Frame, {
      ref: ref,
      display: 'flex',
      className: clsx(
        className,
        prop(alignItems, align),
        prop(justifyContent, distribute),
        prop(reverseStyle, reverse),
        prop(gapStyle(reverse), gap)
      ),
      ...props,
    })
  }
)

const reverseStyle = (reverse) =>
  flexDirection[reverse ? 'reversedColumn' : 'column'] +
  (reverse ? justifyContent.end : '') // @ts-ignore

const gapStyle = (reverse) => (gapProp, queryName) => {
  const reversed =
    !reverse || typeof reverse === 'boolean' ? reverse : reverse[queryName]
  const marginDirection = reversed ? 'bottom' : 'top'
  return ({gap}) =>
    `&>* + *{margin-${marginDirection}:${gap[gapProp]}!important;}`
}
