import _pt from 'prop-types'
import * as React from 'react'
const __reactCreateElement__ = React.createElement
import clsx from 'clsx'
import {Frame} from './Frame'
import {useLayout} from './Layout'

/**
 * A component that makes its items layer on top of each other:
 *   ___
 *  | ☐ |
 *   ‾‾‾
 */
export const Layer = React.forwardRef((props, ref) =>
  /*#__PURE__*/ __reactCreateElement__(Frame, {
    ref: ref,
    position: 'relative',
    ...props,
  })
)
export const LayerItem = React.forwardRef(
  ({className, placement, offset, z, ...props}, ref) => {
    const prop = useLayout().mq.prop
    return /*#__PURE__*/ __reactCreateElement__(Frame, {
      ref: ref,
      position: 'absolute',
      className: clsx(
        className,
        prop(placementStyle(offset), placement),
        prop(zStyle, z)
      ),
      ...props,
    })
  }
)

const placementStyle = (offsetProp) => (value, queryName) => {
  if (value === 'center') {
    return `top:50%;left:50%;transform:translate(-50%,-50%);`
  }

  const offset = !offsetProp
    ? 0
    : typeof offsetProp === 'object'
    ? offsetProp[queryName]
    : offsetProp
  const lValue = value.toLowerCase()
  const yProp =
    lValue.indexOf('top') > -1
      ? 'top'
      : lValue.indexOf('bottom') > -1
      ? 'bottom'
      : void 0
  const xProp =
    lValue.indexOf('left') > -1
      ? 'left'
      : lValue.indexOf('right') > -1
      ? 'right'
      : void 0
  const styles = {}
  if (yProp) styles[yProp] = offset
  if (xProp) styles[xProp] = offset

  if (value === 'left' || value === 'right') {
    styles.top = '50%'
    styles.transform = 'translateY(-50%)'
  }

  if (value === 'bottom' || value === 'top') {
    styles.left = '50%'
    styles.transform = 'translateX(-50%)'
  }

  return styles
}

const zStyle = (value) => ({
  zIndex: value,
})
